@@ -1,4 +1,10 @@
 from . import utils 
 
 
-utils.create('main' , file = dwaretxt ,  description = 'Original Diceware Wordlist')
\ No newline at end of file
+utils.create('main' , file = dwaretxt ,  description = 'Original Diceware Wordlist')
+
+try:
+    utils.cfg.DB.commit()
+    
+except:
+    pass 
\ No newline at end of file
